From: "Michael S. Tsirkin" <mst@redhat.com>
To: Paolo Bonzini <pbonzini@redhat.com>
Cc: "Peter Maydell" <peter.maydell@linaro.org>,
"Anthony Liguori" <aliguori@us.ibm.com>,
qemu-devel@nongnu.org, "Andreas Färber" <afaerber@suse.de>
Subject: Re: [Qemu-devel] [PATCH 00/15] qdev: make reset semantics more clear and consistent, reset qbuses under virtio devices
Date: Wed, 9 Jan 2013 14:10:27 +0200 [thread overview]
Message-ID: <20130109121027.GA18244@redhat.com> (raw)
In-Reply-To: <50ED50B7.4000907@redhat.com>
On Wed, Jan 09, 2013 at 12:12:55PM +0100, Paolo Bonzini wrote:
> Il 09/01/2013 12:09, Michael S. Tsirkin ha scritto:
> > On Wed, Jan 09, 2013 at 11:53:00AM +0100, Paolo Bonzini wrote:
> >> Il 09/01/2013 11:22, Michael S. Tsirkin ha scritto:
> >>>> It's possible. I'll move the SCSI bus away from qdev reset.
> >>>> Anthony/Michael, can you help doing the same with PCIDevice? And
> >>>> perhaps Peter and Andreas with sysbus?
> >>>
> >>> I'm not sure what would you like to change with PCIDevice.
> >>
> >> Replace the DeviceState reset method with one in PCIDevice, and call it
> >> from the PCI bus reset.
> >>
> >> Paolo
> >
> > You are talking about the call to qdev_reset_all(&dev->qdev)
> > in pci_device_reset
>
> Yes.
>
> > , and you want to detect, there, that device is a bridge
> > and replace qdev_reset_all(&dev->qdev) with cast and call to pci_bus_reset
> > for the secondary bus?
>
> The bridge would call pci_bus_reset for its secondary bus in the
> PCIDevice reset method.
>
> I.e. all bus navigation would have to be explicit in the reset
> callbacks. I'm going to do that for the SCSI HBAs.
>
> Paolo
OK you mean like this this? Completely untested - if you
and Anthony think we need this change please let me know
and I'll test and repost.
-->
pci: make secondary bus reset explicit
Signed-off-by: Michael S. Tsirkin <mst@redhat.com>
---
diff --git a/hw/pci/pci.c b/hw/pci/pci.c
index 94840c4..ad81040 100644
--- a/hw/pci/pci.c
+++ b/hw/pci/pci.c
@@ -172,7 +172,7 @@ void pci_device_reset(PCIDevice *dev)
{
int r;
- qdev_reset_all(&dev->qdev);
+ device_reset(&dev->qdev);
dev->irq_state = 0;
pci_update_irq_status(dev);
diff --git a/hw/pci/pci_bridge.c b/hw/pci/pci_bridge.c
index 995842a..a08b479 100644
--- a/hw/pci/pci_bridge.c
+++ b/hw/pci/pci_bridge.c
@@ -258,10 +258,12 @@ void pci_bridge_disable_base_limit(PCIDevice *dev)
pci_set_long(conf + PCI_PREF_LIMIT_UPPER32, 0);
}
/* reset bridge specific configuration registers */
void pci_bridge_reset(DeviceState *qdev)
{
PCIDevice *dev = PCI_DEVICE(qdev);
+ PCIBridge *br = DO_UPCAST(PCIBridge, dev, dev);
uint8_t *conf = dev->config;
conf[PCI_PRIMARY_BUS] = 0;
@@ -295,6 +297,8 @@ void pci_bridge_reset(DeviceState *qdev)
pci_set_long(conf + PCI_PREF_LIMIT_UPPER32, 0);
pci_set_word(conf + PCI_BRIDGE_CONTROL, 0);
+
+ pci_bus_reset(&br->sec_bus);
}
/* default qdev initialization function for PCI-to-PCI bridge */
next prev parent reply other threads:[~2013-01-09 12:06 UTC|newest]
Thread overview: 62+ messages / expand[flat|nested] mbox.gz Atom feed top
2012-12-17 16:24 [Qemu-devel] [PATCH 00/15] qdev: make reset semantics more clear and consistent, reset qbuses under virtio devices Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 01/15] qdev: do not reset a device until the parent has been initialized Paolo Bonzini
2012-12-17 16:52 ` Michael S. Tsirkin
2012-12-17 16:53 ` Michael S. Tsirkin
2012-12-17 17:06 ` Paolo Bonzini
2012-12-17 21:57 ` Andreas Färber
2012-12-17 16:24 ` [Qemu-devel] [PATCH 02/15] intel-hda: do not reset codecs from intel_hda_reset Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 03/15] pci: clean up resetting of IRQs Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 04/15] virtio-pci: reset device before PCI layer Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 05/15] virtio-s390: add a reset function to virtio-s390 devices Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 06/15] qdev: add qbus_reset_all Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 07/15] pci: do not export pci_bus_reset Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 08/15] lsi: use qbus_reset_all to reset SCSI bus Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 09/15] qdev: allow both pre- and post-order vists in qdev walking functions Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 10/15] qdev: switch reset to post-order Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 11/15] qdev: remove device_reset Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 12/15] qdev: document reset semantics Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 13/15] virtio-pci: reset all qbuses too when writing to the status field Paolo Bonzini
2012-12-17 16:48 ` Michael S. Tsirkin
2012-12-17 16:54 ` Paolo Bonzini
2012-12-17 17:08 ` Michael S. Tsirkin
2012-12-17 17:09 ` Paolo Bonzini
2012-12-17 16:24 ` [Qemu-devel] [PATCH 14/15] virtio-s390: " Paolo Bonzini
2012-12-17 16:29 ` Alexander Graf
2012-12-17 16:24 ` [Qemu-devel] [PATCH 15/15] virtio-serial: do not perform bus reset by hand Paolo Bonzini
2012-12-17 21:43 ` [Qemu-devel] [PATCH 00/15] qdev: make reset semantics more clear and consistent, reset qbuses under virtio devices Michael S. Tsirkin
2012-12-18 7:27 ` Paolo Bonzini
2012-12-18 8:35 ` Paolo Bonzini
2012-12-18 9:49 ` Michael S. Tsirkin
2012-12-18 11:40 ` Paolo Bonzini
2013-01-07 17:46 ` Michael S. Tsirkin
2013-01-07 19:10 ` Anthony Liguori
2013-01-07 19:57 ` Peter Maydell
2013-01-07 20:20 ` Anthony Liguori
2013-01-07 20:28 ` Peter Maydell
2013-01-07 20:51 ` Anthony Liguori
2013-01-09 9:33 ` Paolo Bonzini
2013-01-09 10:22 ` Michael S. Tsirkin
2013-01-09 10:53 ` Paolo Bonzini
2013-01-09 11:09 ` Michael S. Tsirkin
2013-01-09 11:12 ` Paolo Bonzini
2013-01-09 12:10 ` Michael S. Tsirkin [this message]
2013-01-09 17:46 ` Paolo Bonzini
2013-01-09 20:40 ` Anthony Liguori
2013-01-09 21:22 ` Paolo Bonzini
2013-01-09 21:40 ` Michael S. Tsirkin
2013-01-10 8:31 ` Paolo Bonzini
2013-01-10 11:32 ` Michael S. Tsirkin
2013-01-10 11:46 ` Peter Maydell
2013-01-10 11:47 ` Paolo Bonzini
2013-01-10 11:59 ` Peter Maydell
2013-01-10 12:12 ` Paolo Bonzini
2013-01-10 12:31 ` Peter Maydell
2013-01-10 12:45 ` Paolo Bonzini
2013-01-10 13:01 ` Peter Maydell
2013-01-10 13:32 ` Paolo Bonzini
2013-01-10 14:14 ` Anthony Liguori
2013-01-10 14:38 ` Paolo Bonzini
2013-01-10 15:01 ` Michael S. Tsirkin
2013-01-08 13:58 ` Michael S. Tsirkin
-- strict thread matches above, loose matches on Subject: below --
2013-01-03 2:18 Anthony Liguori
2013-01-02 18:23 ` Anthony Liguori
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20130109121027.GA18244@redhat.com \
--to=mst@redhat.com \
--cc=afaerber@suse.de \
--cc=aliguori@us.ibm.com \
--cc=pbonzini@redhat.com \
--cc=peter.maydell@linaro.org \
--cc=qemu-devel@nongnu.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -258,10 +258,12 @@ void pci_bridge_disable_base_limit(PCIDevice *dev)
pci_set_long(conf + PCI_PREF_LIMIT_UPPER32, 0);
}
-/* reset bridge specific configuration registers */
+/* reset bridge specific configuration registers.
+ * Propagate reset on the secondary bus. */
void pci_bridge_reset(DeviceState *qdev)
{
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.